package com.tenlionsoft.aimz_k.model

import androidx.room.Dao
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query

@Dao
interface MsgCategoryDao {

    /**
     * 获取全部信息
     *
     * @return
     */
    @Query("SELECT * FROM db_category")
    fun getAllCategory(): List<MsgCategoryBean>

    /**
     * 根据ID获取消息
     *
     * @param id
     * @return
     */
    @Query("SELECT * FROM db_category WHERE id =(:id) ")
    fun getCategoryById(id: String): List<MsgCategoryBean>

    /**
     * 根据信息来源查询消息
     *
     * @param from
     * @return
     */
    @Query("SELECT * FROM db_category WHERE `from`=(:from)")
    fun getCategoryByFrom(from: String?): List<MsgCategoryBean>


    /**
     * 查询与单人的聊天记录  SELECT id FROM db_msg WHERE `from`=(:form) AND `to`=(:to) OR `from`=(:to) AND `to`=(:form) ORDER BY timestamp DESC LIMIT (((:page)-1)*(:pageSize)),(:pageSize)
     */
    @Query("SELECT * FROM db_category t1 ORDER by t1.timestamp ASC LIMIT (((:page)-1)*(:pageSize)),(:pageSize)")
    fun getCategoryPage(
        pageSize: Int,
        page: Int
    ): MutableList<MsgCategoryBean>


    /**
     * 清空与某个人的聊天记录
     */
    @Query("DELETE FROM db_category WHERE `from`=(:from) AND `to`=(:to) OR `from`=(:to) AND `to`=(:from)")
    fun delChatHistory(from: String?, to: String?)

    /**
     * 添加消息多个
     *
     * @param beans
     */
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insertAll(vararg beans: MsgCategoryBean)

    /**
     * 批量添加
     */
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insertAll(beans: List<MsgCategoryBean>)


    /**
     * 添加消息-单个
     *
     * @param bean
     */
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insertMsg(bean: MsgCategoryBean)

    /**
     * 清除全部聊天记录
     */
    @Query("DELETE FROM db_category")
    fun delAllMsg()
}