package com.tenlionsoft.aimz_k.page.activity

import android.view.WindowManager
import androidx.activity.OnBackPressedCallback
import androidx.core.content.ContextCompat
import androidx.databinding.DataBindingUtil
import androidx.fragment.app.Fragment
import com.tenlionsoft.aimz_k.R
import com.tenlionsoft.aimz_k.adapter.VpAdapter
import com.tenlionsoft.aimz_k.databinding.ActivityMainBinding
import com.tenlionsoft.aimz_k.page.fragments.CenterFragment
import com.tenlionsoft.aimz_k.page.fragments.MineFragment
import com.tenlionsoft.aimz_k.page.fragments.MsgFragment
import com.tenlionsoft.baselib.utils.DensityUtils
import com.tenlionsoft.baselib.base.BaseActivity
import com.tenlionsoft.baselib.utils.ToastUtils

/**
 * 首页
 */
class MainActivity : BaseActivity() {
    private lateinit var mBinding: ActivityMainBinding
    private lateinit var mFragments: ArrayList<Fragment>
    private var exitTime: Long = 0
    private var mCurPosition: Int = 0

    override fun bindView() {
        mBinding = DataBindingUtil.setContentView(this, R.layout.activity_main);
        initView();
    }

    /**
     * 初始化页面
     */
    private fun initView() {
        mFragments = ArrayList();
        mFragments.add(MsgFragment.newInstance());
        mFragments.add(CenterFragment.newInstance());
        mFragments.add(MineFragment.newInstance());
        mBinding.vpContent.adapter = VpAdapter(this, mFragments);
        mBinding.bnvTab.itemTextColor = resources.getColorStateList(R.color.col_tabs, theme);
        mBinding.bnvTab.itemIconSize = DensityUtils.dp2px(this, 24F);
        mBinding.vpContent.isUserInputEnabled = false;
        mBinding.bnvTab.setOnItemSelectedListener { item ->
            when (item.itemId) {
                R.id.menu_item_msg -> {
                    setStatusBarColor(true);
                    mBinding.vpContent.setCurrentItem(0, false);
                    mCurPosition = 0;
                    return@setOnItemSelectedListener true;
                }//首页
                R.id.menu_item_center -> {
                    setStatusBarColor(true);
                    mBinding.vpContent.setCurrentItem(1, false);
                    mCurPosition = 1;
                    return@setOnItemSelectedListener true;
                }//统计
                R.id.menu_item_mine -> {
                    setStatusBarColor(false);
                    mBinding.vpContent.setCurrentItem(2, false);
                    mCurPosition = 2;
                    return@setOnItemSelectedListener true;
                }//我的
            }
            false;
        }

        onBackPressedDispatcher.addCallback(this, object : OnBackPressedCallback(true) {
            override fun handleOnBackPressed() {
                if (mCurPosition == 0) {
                    if ((System.currentTimeMillis() - exitTime) > 2000) {
                        ToastUtils.normal("再按一次退出程序")
                        exitTime = System.currentTimeMillis();
                    } else {
                        exitApp();
                    }
                } else {
                    mBinding.bnvTab.selectedItemId = R.id.menu_item_msg
                }
            }
        })
    }

    fun setStatusBarColor(dark: Boolean) {
        val window = window
        if (dark) {
            window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS)
            window.statusBarColor = ContextCompat.getColor(this, com.tenlionsoft.baselib.R.color.tr)
        } else {
            window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS)
            window.statusBarColor = ContextCompat.getColor(this, R.color.white)
        }

    }
}


