package com.tenlionsoft.aimz_k.services

import android.annotation.SuppressLint
import android.app.Notification
import android.app.NotificationChannel
import android.app.NotificationManager
import android.app.Service
import android.content.Intent
import android.os.Build
import android.os.IBinder
import com.tenlionsoft.aimz_k.R
import com.tenlionsoft.aimz_k.socket.WsManager
import com.tenlionsoft.baselib.contacts.ProjectConfig


/**
 * Socket service
 */
class SocketService : Service() {
    private var mWsManager: WsManager? = null
    override fun onCreate() {
        super.onCreate()
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            val channel = NotificationChannel(
                ProjectConfig.NOTIFY_CHANNEL_ID, "Ai秒著客服",
                NotificationManager.IMPORTANCE_DEFAULT
            )
            val manager = getSystemService(NotificationManager::class.java)
            manager.createNotificationChannel(channel)
        }
    }


    @SuppressLint("ForegroundServiceType")
    override fun onStartCommand(intent: Intent?, flags: Int, startId: Int): Int {
        val builder: Notification.Builder
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            builder = Notification.Builder(this, ProjectConfig.NOTIFY_CHANNEL_ID)
        } else {
            builder = Notification.Builder(this)
        }
        builder.setContentTitle("Ai秒著")
            .setContentText("聊天已经登陆")
            .setSmallIcon(R.drawable.app_logo_small)
        val notification: Notification = builder.build()
        startForeground(startId, notification)

        this.startSocket();//开启Socket
        return START_STICKY
    }

    /**
     * 开启链接socket
     */
    fun startSocket() {
        if (mWsManager == null) {
            mWsManager = WsManager.Builder(applicationContext)
                .wsUrl(ProjectConfig.SOCKET_MSG_SECRET)
                .needReconnect(true)
                .build()
        }
        if (!mWsManager!!.isWsConnected()) {
            mWsManager!!.startConnect();
        }

    }

    fun stopSocket() {
        if (mWsManager != null && mWsManager!!.isWsConnected()) {
            mWsManager!!.stopConnect();
            mWsManager = null;
        }
    }

    override fun onBind(intent: Intent?): IBinder? {
        return null;
    }

    override fun onDestroy() {
        stopSocket();
        super.onDestroy()
    }
}