package com.tenlionsoft.aimz_k.viewmodel

import android.util.Log
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.tenlionsoft.aimz_k.model.DbManager
import com.tenlionsoft.aimz_k.model.MsgCategoryBean
import com.tenlionsoft.aimz_k.widget.CategoryAdapter
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

class MsgViewModel : ViewModel() {
    private val _pwdList = MutableLiveData<List<MsgCategoryBean>>()
    var adapter: CategoryAdapter = CategoryAdapter(_pwdList.value ?: emptyList(),this)
    var onItemClickListener: OnItemClickListener? = null

    private var mCurrentPage: Int = 1
    var isHasMore: MutableLiveData<Boolean> = MutableLiveData<Boolean>().apply {
        value = false
    }

    init {
        Log.e("MsgViewModel", "Init:${_pwdList.value} ")
        getPwdList(true)
    }


    /**
     * 获取列表数据
     */
    private fun getPwdList(isFirst: Boolean) {
        viewModelScope.launch {
            if (isFirst) {
                _pwdList.value = emptyList()
                mCurrentPage = 1
            } else {
                ++mCurrentPage
            }
            val list = getCategoryListByPage(mCurrentPage)
            if (list.isNotEmpty()) {
                isHasMore.value = false
            } else {
                isHasMore.value = true
            }
            val updateData: List<MsgCategoryBean> = _pwdList.value!! + list
            _pwdList.value = updateData
            Log.e("MsgViewModel", "getPwdList: ${_pwdList.value}")
            adapter.setData(_pwdList.value!!)
        }
    }

    private suspend fun getCategoryListByPage(page: Int): List<MsgCategoryBean> {
        var tempList: List<MsgCategoryBean>
        withContext(Dispatchers.IO) {
            val cDao = DbManager.db.categoryDao()
            tempList = cDao.getCategoryPage(10, page)
        }
        return tempList
    }

    /**
     * 加载更多
     */
    fun loadMore() {
        getPwdList(false)
    }

    /**
     * 刷新
     */
    fun refresh() {
        getPwdList(true)
    }

    interface OnItemClickListener {
        fun onItemClick(msgCategoryBean: MsgCategoryBean)
    }
}