package com.tenlionsoft.baselib.base

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.databinding.DataBindingUtil
import androidx.databinding.ViewDataBinding
import androidx.lifecycle.LifecycleOwner
import androidx.lifecycle.ViewModel
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.RecyclerView.ViewHolder

/**
 * Adapter基类
 */
abstract class BaseBindingAdapter<V : ViewModel, CV : ViewDataBinding>(private val viewModel: V) :
    RecyclerView.Adapter<BaseBindingAdapter.BaseViewHolder<CV>>() {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): BaseViewHolder<CV> {
        val layoutInflater = LayoutInflater.from(parent.context)
        val binding = DataBindingUtil.inflate<CV>(
            layoutInflater,
            setItemLayout(),
            parent,
            false
        )
        binding.lifecycleOwner = parent.context as LifecycleOwner
        return BaseViewHolder(binding)
    }

    abstract fun setItemLayout(): Int
    abstract fun bindDataToItem(h: BaseViewHolder<CV>, position: Int, viewModel: V)
    override fun onBindViewHolder(holder: BaseViewHolder<CV>, position: Int) {
        bindDataToItem(holder, position, viewModel)
    }

    class BaseViewHolder<CV : ViewDataBinding>(cv: CV) : ViewHolder(cv.root) {
        var itemBinding = cv
    }
}