package com.tenlionsoft.baselib.utils

import android.util.Base64
import java.security.SecureRandom
import javax.crypto.Cipher
import javax.crypto.KeyGenerator
import javax.crypto.SecretKey
import javax.crypto.spec.IvParameterSpec
import javax.crypto.spec.SecretKeySpec


class AesUtil {
    companion object {
        private val IV_STRING: String = "16-Bytes--String"

        /**
         * AES加密
         *
         * @param encodeRule
         * @param content
         * @return
         * @throws Exception
         */
        @Throws(Exception::class)
        fun aesEncoder(encodeRule: String, content: String): String {
            // 1.构造秘钥生成器
            val keyGenerator = KeyGenerator.getInstance("AES")
            // 2.根据编码规则构建秘钥生成器
            val random = SecureRandom.getInstance("SHA1PRNG")
            random.setSeed(encodeRule.toByteArray())
            keyGenerator.init(128, random)
            // 3.产生堆成秘钥
            val secretKey = keyGenerator.generateKey()
            // 4.对称秘钥原始数组
            val secretKeyByte = secretKey.encoded
            // 5.生成AES秘钥
            val key: SecretKey = SecretKeySpec(secretKeyByte, "AES")
            // 6.初始化密码器
            val cipher = Cipher.getInstance("AES")
            cipher.init(Cipher.ENCRYPT_MODE, key)
            // 8.获取加密内容字节数组
            val contentByte = content.toByteArray(charset("UTF-8"))
            // 9.加密
            return String(Base64.encode(cipher.doFinal(contentByte), Base64.DEFAULT))
        }

        /**
         * AES解密
         *
         * @param encodeRule
         * @param content
         * @return
         * @throws Exception
         */
        @Throws(Exception::class)
        fun aesDecoder(encodeRule: String, content: String?): String {
            // 1.构建秘钥生成器
            val keyGenerator = KeyGenerator.getInstance("AES")
            // 2.根据编码规则构建秘钥生成器
            val random = SecureRandom.getInstance("SHA1PRNG")
            random.setSeed(encodeRule.toByteArray())
            keyGenerator.init(128, random)
            // 3.生成对称解密秘钥
            val secretKey = keyGenerator.generateKey()
            // 4.对称秘钥原始数组
            val secretKeyByte = secretKey.encoded
            // 5.生成AES秘钥
            val key: SecretKey = SecretKeySpec(secretKeyByte, "AES")
            // 6.初始化密码器
            val cipher = Cipher.getInstance("AES")
            cipher.init(Cipher.DECRYPT_MODE, key)
            // 7.要解密内容的字节数组
            val contentByte: ByteArray = Base64.decode(content, Base64.DEFAULT)
            //         Base64.decodeBase64(content);
            // 8.解密
            return String(cipher.doFinal(contentByte), charset("UTF-8"))
        }

        /**
         * 通用aes加密，兼容IOS
         *
         * @param key
         * @param content
         * @return
         * @throws Exception
         */
        @Throws(Exception::class)
        fun aesCommonEncoder(key: String, content: String): String {
            val byteContent = content.toByteArray(charset("UTF-8"))
            val enCodeFormat = key.toByteArray()
            val secretKeySpec = SecretKeySpec(enCodeFormat, "AES")
            val initParam = IV_STRING.toByteArray()
            val ivParameterSpec = IvParameterSpec(initParam)
            val cipher = Cipher.getInstance("AES/CBC/PKCS5Padding")
            cipher.init(Cipher.ENCRYPT_MODE, secretKeySpec, ivParameterSpec)
            val encryptedBytes = cipher.doFinal(byteContent)
            return String(Base64.encode(encryptedBytes, Base64.DEFAULT), charset("UTF-8"))
        }

        /**
         * aes通用解密，兼容IOS
         *
         * @param key
         * @param content
         * @return
         * @throws Exception
         */
        @Throws(Exception::class)
        fun aesCommonDecoder(key: String, content: String?): String {
            val encryptedBytes: ByteArray = Base64.decode(content, 0)
            val enCodeFormat = key.toByteArray()
            val secretKey = SecretKeySpec(enCodeFormat, "AES")
            val initParam = IV_STRING.toByteArray()
            val ivParameterSpec = IvParameterSpec(initParam)
            val cipher = Cipher.getInstance("AES/CBC/PKCS5Padding")
            cipher.init(Cipher.DECRYPT_MODE, secretKey, ivParameterSpec)
            val result = cipher.doFinal(encryptedBytes)
            return String(result, charset("UTF-8"))
        }


        //    public static final byte[] a = new byte[]{
        //        120, 119, 57, 80, 52, 110, 102, 56, 114, 66,
        //        75, 75, 65, 110, 119, 53};

        val a: ByteArray = byteArrayOf(
            120, 119, 57, 80, 52, 110, 102, 56, 114, 66,
            75, 75, 65, 110, 119, 53
        )

        fun test(paramString: String): String? {
            val arrayOfByte = "1234567890123456".toByteArray()
            val secretKeySpec = SecretKeySpec(a, "AES")
            try {
                val cipher = Cipher.getInstance("AES/CBC/PKCS5Padding")
                cipher.init(1, secretKeySpec, IvParameterSpec(arrayOfByte))
                val bytes = cipher.doFinal(paramString.toByteArray())
                return String(Base64.encode(bytes, Base64.NO_PADDING), charset("UTF-8"))
            } catch (exception: Exception) {
                exception.printStackTrace()
                return null
            }
        }
    }
}