package com.tenlionsoft.baselib.utils

import android.content.pm.PackageManager
import android.os.Build
import com.tenlionsoft.baselib.base.App
import java.io.File
import java.io.IOException
import java.util.UUID


class AppUtils {
    companion object {
        fun getAppVersionName(): String {
            return getAppVersionName(App.context.packageName)
        }

        private fun getAppVersionName(pkgName: String?): String {
            if (pkgName.isNullOrEmpty()) return ""
            try {
                val pm = App.context.packageManager
                val pi = pm.getPackageInfo(pkgName, 0)
                return pi?.versionName ?: ""
            } catch (e: PackageManager.NameNotFoundException) {
                e.printStackTrace();
                return ""
            }
        }

        fun getAppVersionCode(): Long {
            return getAppVersionCode(App.context.packageName)
        }

        private fun getAppVersionCode(pkgName: String?): Long {
            if (pkgName.isNullOrEmpty()) return -1
            try {
                val pm = App.context.packageManager
                val pi = pm.getPackageInfo(pkgName, 0);
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
                    return pi?.longVersionCode ?: -1
                } else {
                    return (pi?.versionCode ?: -1).toLong()
                }
            } catch (e: PackageManager.NameNotFoundException) {
                e.printStackTrace()
                return -1
            }
        }

        fun getDeviceId(): String {
            val filePath: String =
                App.context.getExternalFilesDir("Cache")
                    ?.absolutePath + File.separator + "identity.txt"
            val file = File(filePath)
            var uuid: String? = ""
            if (!file.exists()) {
                try {
                    val newFile = file.createNewFile()
                    uuid = UUID.randomUUID().toString()
                    FileIOUtils.writeFileFromString(file, uuid)
                } catch (e: IOException) {
                    e.printStackTrace()
                }
            } else {
                uuid = FileIOUtils.readFile2String(file)
            }
            return uuid!!
        }
    }
}