package com.tenlionsoft.baselib.widget

import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.MotionEvent
import android.widget.LinearLayout
import androidx.databinding.DataBindingUtil
import androidx.lifecycle.LifecycleOwner
import com.tenlionsoft.baselib.R
import com.tenlionsoft.baselib.databinding.CustomLoadingViewBinding
import com.tenlionsoft.baselib.model.ViewState

/**
 * 自定义loading view
 */
class CustomLoadingView : LinearLayout {
    private lateinit var mBinding: CustomLoadingViewBinding
    private lateinit var mCurrentState: ViewState

    constructor(context: Context) : this(context, null)
    constructor(context: Context?, attrs: AttributeSet?) : this(context, attrs, 0)
    constructor(context: Context?, attrs: AttributeSet?, defaultStyle: Int) : super(
        context,
        attrs,
        defaultStyle
    ) {
        initView()
    }

    private fun initView() {
        val inflater = LayoutInflater.from(context)
        mBinding = DataBindingUtil.inflate(inflater, R.layout.custom_loading_view, this, true)
        mBinding.lifecycleOwner = this.context as LifecycleOwner
    }

    override fun dispatchTouchEvent(ev: MotionEvent?): Boolean {
        return isCanClick()
    }

    @SuppressLint("ClickableViewAccessibility")
    override fun onTouchEvent(event: MotionEvent?): Boolean {
        return isCanClick()
    }

    override fun onInterceptTouchEvent(ev: MotionEvent?): Boolean {
        return isCanClick()
    }

    private fun isCanClick(): Boolean {
        return this.mCurrentState == ViewState.STATE_LOAD
    }

    /**
     * 设置状态
     */
    fun setState(state: ViewState) {
        this.mCurrentState = state
        when (state) {
            ViewState.STATE_LOAD -> {
//                this.visibility= VISIBLE
                mBinding.llStateHint.visibility = VISIBLE
                mBinding.ivStateData.visibility = GONE
                mBinding.pbStateLoading.visibility = VISIBLE
                mBinding.tvStateHint.visibility = VISIBLE
                mBinding.tvStateHint.text = "加载中..."
            }

            ViewState.STATE_EMPTY -> {
                mBinding.llStateHint.visibility = VISIBLE
                mBinding.ivStateData.visibility = VISIBLE;
                mBinding.ivStateData.setBackgroundResource(R.drawable.ic_empty_data);
                mBinding.pbStateLoading.visibility = GONE;
                mBinding.tvStateHint.visibility = VISIBLE;
                mBinding.tvStateHint.text = "暂无数据";
            }

            ViewState.STATE_ERROR -> {
                mBinding.llStateHint.visibility = VISIBLE
                mBinding.ivStateData.visibility = VISIBLE;
                mBinding.ivStateData.setBackgroundResource(R.drawable.ic_load_error);
                mBinding.pbStateLoading.visibility = GONE;
                mBinding.tvStateHint.visibility = VISIBLE;
                mBinding.tvStateHint.text = "加载失败";
            }

            ViewState.STATE_SUCCESS -> {
                mBinding.llStateHint.visibility = GONE
                mBinding.ivStateData.visibility = GONE;
                mBinding.pbStateLoading.visibility = GONE;
                mBinding.tvStateHint.visibility = GONE;
            }

            ViewState.STATE_SEARCH -> {
                mBinding.llStateHint.visibility = VISIBLE
                mBinding.ivStateData.visibility = VISIBLE;
                mBinding.ivStateData.setBackgroundResource(R.drawable.ic_empty_data);
                mBinding.pbStateLoading.visibility = GONE;
                mBinding.tvStateHint.visibility = VISIBLE;
                mBinding.tvStateHint.text = "请输入要查询的内容";
            }

            ViewState.STATE_ERROR_NET -> {}
        }
    }
}