package com.tenlionsoft.baselib.widget

import android.app.Activity
import android.app.Dialog
import android.content.Context
import android.content.DialogInterface
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.widget.TextView
import com.tenlionsoft.baselib.R


class LoadingDialog : Dialog {
    constructor(context: Context) : super(context)

    constructor(context: Context, themeResId: Int) : super(context, themeResId)

    constructor(context: Context, cancelable: Boolean, cancelListener: DialogInterface.OnCancelListener?) : super(context, cancelable, cancelListener)

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
//        val displayMetrics = context.resources.displayMetrics
        val window = this.window
        window!!.setGravity(Gravity.CENTER)
        window.setWindowAnimations(R.style.dialog_style)
        //TODO 设置Dialog的大小
//        val params = window.attributes
//        params.width = (displayMetrics.widthPixels * 0.9).toInt()
//        params.height = WindowManager.LayoutParams.WRAP_CONTENT
//        window.attributes = params
        window.setBackgroundDrawable(ColorDrawable())
    }

    class Builder(private val context: Activity) {
        //提示信息
        private var message: String? = null

        //是否展示提示信息
        private var isShowMessage = true

        //是否按返回键取消
        private var isCancelable = true

        //是否取消
        private var isCancelOutside = false

        /**
         * 设置提示信息
         * @param message
         * @return
         */
        fun setMessage(message: String?): Builder {
            this.message = message
            return this
        }

        /**
         * 设置是否显示提示信息
         * @param isShowMessage
         * @return
         */
        fun setShowMessage(isShowMessage: Boolean): Builder {
            this.isShowMessage = isShowMessage
            return this
        }

        /**
         * 设置是否可以按返回键取消
         * @param isCancelable
         * @return
         */
        fun setCancelable(isCancelable: Boolean): Builder {
            this.isCancelable = isCancelable
            return this
        }

        /**
         * 设置是否可以取消
         * @param isCancelOutside
         * @return
         */
        fun setCancelOutside(isCancelOutside: Boolean): Builder {
            this.isCancelOutside = isCancelOutside
            return this
        }

        //创建Dialog
        fun create(): LoadingDialog {
            val inflater = LayoutInflater.from(context)
            val view: View = inflater.inflate(R.layout.dialog_loading, null)
            //设置带自定义主题的dialog
            val loadingDailog = LoadingDialog(context, R.style.dialog_style)
            val textView = view.findViewById<TextView>(R.id.tipTextView)
            textView.text = message
            loadingDailog.setContentView(view)
            loadingDailog.setCancelable(isCancelable)
            loadingDailog.setCanceledOnTouchOutside(isCancelOutside)
            return loadingDailog
        }
    }
}